Monty Python's Flying Circus: Just the Words - Episode 9

# Episode Nine: The ant, an introduction

Llamas
A man with a tape recorder up his nose
Kilimanjaro expedition (double vision)
A man with a tape recorder up his brother's nose
Homicidal barber
Lumberjack song
Gumby crooner
The refreshment room at Bletchley
Hunting film
The visitors

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A forest. From an explosion in the far distance the 'It's' man runs very rapidly up to camera and announces:
It's Man | It's...
Voice Over | (and CAPTION:) 'MONTY PYTHON'S FLYING CIRCUS'
| Opening animated titles. CAPTION: 'PART 2' CAPTION 'THE LLAMA' A Spanish guitarist (Eric) and a dancer (Terry J) in traditional spanish costume. SUPERIMPOSED CAPTION: 'LIVE FROM GOLDERS GREEN' Man enters and walks up to a life-size photo of a llama. He delivers the following lecture in Spanish, with help from the guitarist and dancer, and superimposed subtitles.
Man | (but in Spanish with subtitles in English) The llama is a quadruped which lives in the big rivers like the Amazon. It has two ears, a heart, a forehead, and a beak for eating honey. But it is provided with fins for swimming.
Guitarist & Dancer | Llamas are larger than frogs.
Man | Llamas are dangerous, so if you see one where people are swimming, you shout...
Guitarist & Dancer | Look out, there are llamas!
| Graham dressed in a spanish frock, enters on a moped; he blows up a paper bag and bursts it. They bow. Cut to exterior Ada's Snack Bar (a small cafe). Hand-held camera moves round the back to where an announcer is seated at desk with an old-fashioned BBC microphone.
Announcer | And now for something completely different - a man with a tape recorder up his nose.
| We see Michael, in evening dress, on a small stage, with potted plants, etc. He ostentatiously inserts a finger up one nostril. We hear the Marseillaise. He removes the finger; the music stops. He inserts the finger up the other nostril: we hear rewinding noises. Once again he inserts a finger up the first nostril: again we hear the Marseillaise. He bows. Stock film of Women's Institute applauding. He inserts a finger up his nostril again, and we hear:
Voice Over | And now for something completely different. The office of Sir George Head, OBE.
| Large study with maps and photographs on the wall and a large desk at which sits Sir George Head.
Sir | Next please.
| Arthur walks into the room and up to the desk.
Sir | (looking up) One at a time please.
Bob | There is only me, sir.
Sir | (putting a hand over one eye) So there is. Take a . . .
Bob | Seat?
Sir | Seat! Take a seat. So! (looking over to Bob's right) You want to join my mountaineering expedition do you? (keeps looking off to right)
Bob | (rather uncertain) Me, sir?
Sir | Yes.
Bob | Yes, I'd very much like to, sir.
Sir | Jolly good, jolly good. (he ticks the sheet and then looks straight at Bob) And how about you?
Bob | There is only me, sir.
Sir | (putting hand over eye and looking both at Bob and to Bob's right) Well bang goes his application then. (he tears up form) Now let me fill you in. I'm leading this expedition and we're going to climb both peaks of Mount Kilimanjaro.
Bob | I thought there was only one peak, sir.
Sir | (getting up, putting one hand over one eye again and going to large map of Africa on wall and peering at it at point-blank range) Well, that'll save a bit of time. Well done. Now the object of this expedition is to see if we can find any traces of last year's expedition.
Bob | Last year's expedition?
Sir | Yes, my brother was leading that, they were going to build a bridge between the two peaks, (looks at map with one hand over eye) My idea I'm afraid. Now, I ought to tell you that I have practically everyone I need for this expedition ... so what special qualifications do you have?
Bob | Well, sir...
Sir | Yes, you first.
Bob | There is only me, sir.
Sir | (to Bob's right) I wasn't talking to you. (to Bob) Carry on.
Bob | Well I'm a fully qualified mountaineer.
Sir | Mountaineer? Mountaineer (looks it up in the dictionary) where the devil are they, mound, mount... mountain... a mountaineer: 'two men skilled in climbing mountains'. Jolly good, well you're in. Congratulations, both of you. Well, er, what are your names?
Bob | Arthur Wilson.
Sir | Arthur Wilson, right well look, I'll call you (to Bob) Arthur Wilson one, and you (to Bob's right) Arthur Wilson two, just to avoid confusion.
Bob | Are you actually leading this expedition sir?
Sir | Yes, we are leading this expedition to Africa.
Bob | And what routes will you both be taking?
Sir | Good questions... shall I? Well we'll be leaving on January 22nd and taking the following routes. (goes over to large map, clearly labelled Surrey) The A23s through Purleys down on the main roads near Purbrights avoiding Leatherheads and then taking the A231s entering Rottingdeans from the North. From Rottingdeans we go through Africa to Nairobis. We take the South road out of Nairobis for about twelve miles and then ask.
Bob | Does anyone speak Swahili, sir?
Sir | Oh, yes I think most of them do down there.
Bob | Does anyone in our party speak Swahili sir?
Sir | Oh, well Matron's got a smattering.
Bob | Apart from the two Matrons ...
Sir | Good God, I'd forgotten about her.
Bob | Apart from them, who else is coming on the expedition, sir?
Sir | Well we've got the Arthur Brown twins, two botanists called Machin, the William Johnston brothers ...
Bob | Two of them?
Sir | No four of them, a pair of identical twins ... and a couple of the Ken Spinoza quads - the other two pulled out. And of course you two.
Bob | And none of these are mountaineers?
Sir | Well you two are, and we've got a brace of guides called Jimmy Blenkinsop... because Kilimanjaro is a pretty tricky climb you know, most of it's up until you reach the very very top, and then it tends to slope away rather sharply. But Jimmy's put his heads together and worked out a way up. (opens door) Jimmy? (Jimmy walks in wearing full climbing gear) I don't believe you've met. Jimmy Blenkinsop - Arthur Wilson, Arthur Wilson -Jimmy Blenkinsop... Arthur Wilson two -James Blenkinsop one, James Blenkinsop one - Arthur Wilson two. Carry on Jimmies.
Jimmy | (to Bob, reassuring him) Don't worry about the er ... (puts hand over eye) We'll get him up somehow. Jimmy proceeds to walk round the room clambering over every single piece of available furniture. He doesn't stop talking. Causing a complete wreckage, he clambers over the desk, onto a bookcase and round the room knocking furniture over, meanwhile he is saying.. Now the approach to Kilimanjaro is quite simply over the foothills, and then we go on after that to ... ohh... to set a base camp, somewhere in the region of the bottom of the glacier when... Jimmy staggers out headlong through the door. There are loud crashing noises
Sir | He'll be leading the first assault.
Bob | Well I'm afraid I shan't be coming on your expedition sir, as I've absolutely no confidence in anyone involved in it.
| Bob gets up and walks out slamming the door.
Sir | Oh dear. (pause - look over at other? Bob) Well how about you?
Bob | (sitting in chair at other angle of desk) Well I'm game, sir.
| Cut back to two sirs, double image, split screen.
Sir | So are we.
| Cut to two announcers (Johns) at desks. They put telephones down, turns to camera, and announce:
Announcers | And now for aomething completely different - a man with a tape recorder up his brother's nose.
| Cut to Michael on small stage as before, this time also with Graham. Michael puts a finger up Graham's nostril: we hear the Marseillaise. He removes it: the music stops. He puts a finger up Graham's other nostril, and we hear rewinding noises.
Voice Over | (and CAPTION:) 'AND NOW IN STEREO...'
| Michael simultaneously puts a finger up his own nostril and a finger (on the other hand) up Graham's; we hear two recordings of the Marseillaise together (out of sync). An animated sequence then leads us to a gents suburban hairdressing salon. A customer comes in. The barber is standing in a white coat washing his hands at a basin.
Customer | Morning.
Barber | (flinching slightly) Ah ... good morning sir, good morning. I'll be with you in a minute.
| Customer sits in barber's chair. Barber carries on washing. He seems to be over-thoroughly washing and rewashing his hands and lower arms. Barber turns and smiles humourlessly, at customer. At last he has finished washing. He dries his hands thoroughly, turns and comes over to the customer. There are very obvious blood stains on his coat and his lapel is torn off. One stain could be the mark of a bloodstained hand which has slipped down the length of it. He picks up a sheet and shakes it out. Sound of iron and heavy objects falling on the floor. He throws it around the customer. As he knots the sheet at the back he is about to pull it tight and strangle the customer. His face sweats, a wild look in his eyes. Then with a supreme effort he controls himself. Customer smiles reassuringly at him.
Barber | How... how would you like it, sir?
Customer | Just short back and sides please.
Barber | How do you do that?
Customer | Well it's just... ordinary short back and sides.
Barber | It's not a ... razor cut? (suddenly) Razor, razor, cut, cut, blood, spurt, artery, murder... (controlling himself) Oh thank God, thank God. (sigh of relief) It's just a scissors.
Customer | Yes... (laughs, thinking the barber must be having a little joke)
Barber | You wouldn't rather just have it combed, would you sir?
Customer | I beg your pardon?
Barber | You wouldn't rather forget all about it?
Customer | No, no, no, I want it cut.
| At the word cut barber winces.
Barber | Cut, cut, cut, blood, spurt, artery, murder, Hitchcock, Psycho... right sir ... well ... (swallows hard) I'll just get everything ready. In the meanwhile perhaps you could fill in one of these.
| He hands him a bit of paper; the barber goes to a cupboard and opens it.
Customer | All right, fine, yes.
| On the inside of the door there is a large medical chart headed: 'Main Arteries'. His shaking hand traces the arteries and he looks occasionally back at the customer.
Customer | Excuse me, er...
Barber | What?
Customer | Where it says: 'next of kin' shall I put 'mother'?
Barber | Yes, yes ... yes.
Customer | Right there we are. (hands form to barber)
Barber | Thank you.
| He gets scissors and comb ready and comes up behind the customer and spreads his arms out, opening and shutting scissors as barbers do before cutting.
Barber | Right!
| He can't bring himself to start cutting; after one or two attempts he goes to the cupboard again, gets a whisky bottle out and takes a hard swig. He comes up behind the customer again.
Barber | Ha, ha, ha ... there, I've finished.
Customer | What?
Barber | I've finished cutting... cutting... cutting your hair. It's all done,
Customer | You haven't started cutting it!
Barber | I have! I did it very quickly... your honour... sir... sir...
Customer | (getting rather testy) Look here old fellow, I know when a chap's cut my hair and when he hasn't. So will you please stop fooling around and get on with it.
| The barber bends down to the floor and drags out a tape recorder which he places behind the barber's chair, talking as he does so.
Barber | Yes, yes, I will, I'm going to cut your hair, sir. I'm going to start cutting your hair, sir, start cutting now!
| He switches on tape recorder and then he himself cowers down against the wall as far from the chair as he can get, trembling.
Tape Recorder | Nice day, sir,
Customer | Yes, flowers could do with a drop of rain though, eh?
Tape Recorder | (snip, snip) Did you see the match last night, sir?
Customer | Yes. Good game. I thought.
Tape Recorder | (snip, snip, snip; sound of electric razor starting up) I thought Hurst played well sir.
Customer | (straining to hear) I beg your pardon?
Tape Recorder | (razor stops) I thought Hurst played well.
Customer | Oh yes ... yes ... he was the only one who did though.
Tape Recorder | Can you put your head down a little, sir?
Customer | Sorry, sorry. (his head is bowed)
Tape Recorder | I prefer to watch Palace nowadays. (electric razor starts up again) Oh! Sorry! Was that your ear?
Customer | No no ... I didn't feel a thing.
| The customer rises out from his seat, taking the sheet off himself and looking in the mirror and delving into pocket. He turns round for the first time and sees the cowering barber.
Customer | Look, what's going on?
Tape Recorder | Yes, it's a nice spot, isn't it.
Customer | Look, I came here for a haircut!
Barber | (pathetically) It looks very nice sir.
Customer | (angrily) It's exactly the same as when I first came in.
Tape Recorder | Right, that's the lot then.
Barber | All right ... I confess I haven't cut your hair ... I hate cutting hair. I have this terrible un-un-uncontrollable fear whenever I see hair. When I was a kid I used to hate the sight of hair being cut. My mother said I was a fool. She said the only way to cure it was to become a barber. So I spent five ghastly years at the Hairdressers' Training Centre at Totnes. Can you imagine what it's like cutting the same head for five years? I didn't want to be a barber anyway. I wanted to be a lumberjack. Leaping from tree to tree as they float down the mighty rivers of British Columbia . . . (he is gradually straightening up with a visionary gleam in his eyes) The giant redwood, the larch, the fir, the mighty scots pine. (he tears off his barber's jacket, to reveal tartan shirt and lumberjack trousers underneath; as he speaks the lights dim behind him and a choir of Mounties is heard, faintly in the distance) The smell of fresh-cut timber! The crash of mighty trees! (moves to stand infront of back-drop of Canadian mountains and forests) With my best girlie by my side ... (a frail adoring blonde, the heroine of many a mountains film, or perhaps the rebel maid, rushes to his side and looks adoringly into his eyes) We'd sing ... sing ... sing.
| The choir is loud by now and music as well.
Barber | (singing) I'm a lumberjack and I'm OK, I sleep all night and I work all day
| Light comes up to his left to reveal a choir of Mounties.
Mounties Choir | He's a lumberjack, and he's OK, He sleeps all night and he works all day.
Barber | I cut down trees, I eat my lunch, I go to the lavatory. On Wednesdays I go shopping, And have buttered scones for tea.
Mounties Choir | He cuts down trees, He eats his lunch, He goes to the lavatory. On Wednesdays he goes shopping, And have buttered scones for tea. He's a lumberjack, and he's OK, He sleeps all night and he works all day.
Barber | I cut down trees, I skip and jump, I like to press wild flowers. I put on women's clothing, And hang around in bars.
Mounties Choir | He cuts down trees, he skips and jumps, He likes to press wild flowers. He puts on women's clothing And hangs around.... In bars???????
| During the last verse the choir has started to look uncomfortable but they brighten up as they go into the chorus.
Mounties Choir | He's a lumberjack, and he's OK, He sleeps all night and he works all day.
Barber | I chop down trees, I wear high heels, Suspenders and a bra. I wish I'd been a girlie Just like my dear Mama.
Mounties Choir | He cuts down trees, he wears high heels (spoken rather than sung)Suspenders and a .... a Bra????
| They all mumble. Music runs down. The girl looks horrified and bursts into tears.
Barber | ...just like my dear Mama.
Girl (Connie Booth) | Oh Bevis! And I thought you were so rugged.
| Cut to hand-written letter.
Voice Over | Dear Sir, I wish to complain in the strongest possible terms about the song which you have just broadcast, about the lumberjack who wears women's clothes. Many of my best friends are lumberjacks and only a few of them are transvestites. Yours faithfully, Brigadier Sir Charles Arthur Strong (Mrs.) PS I have never kissed the editor of the Radio Times.
| Cut to pepperpot.
Pepperpot | Well I object to all this sex on the television. I mean I keep falling off.
| Shot of battered trophy. SUPERIMPOSED CAPTION: 'THAT JOKE WAS BRITAIN'S ENTRY FOR THIS YEAR'S RUBBER MAC OF ZURICH AWARD' ROLLER CAPTION: 'IT CAME LAST' Cut back to Canadian backdrop. In front, a man with a knotted handkerchief on his head, a wooly pullover, and braces. SUPERIMPOSED CAPTION: 'PROF. R. J. GUMBY'
Gumby | Well I think television's killed real entertainment. In the old days we used to make our own fun. At Christmas parties I used to strike myself on the head repeatedly with blunt instruments while crooning. (sings) 'Only make believe, I love you, (hits himself on head with bricks) Only make believe that you love me, (hits himself) Others find peace of mind...'
| Cut to a swish nightclub. Compère enters.
Compère | Good evening, ladies and gentlemen, and welcome to the Refreshment Room here at Bletchley. (applause) My name is Kenny Lust and I'm your compère for tonight. You know, once in a while it is my pleasure, and my privilege, to welcome here at the Refreshment Room, some of the truly great international artists of our time. (applause) And tonight we have one such artist. (grovelling) Ladies and gentlemen, someone whom I've always personally admired, perhaps more deeply, more strongly, more abjectly than ever before. (applause) A man, well more than a man, a god (applause), a great god, whose personality is so totally and utterly wonderful my feeble words of welcome sound wretchedly and pathetically inadequate. (by now on his knees) Someone whose boots I would gladly lick clean until holes wore through my tongue, a man who is so totally and utterly wonderful, that I would rather be sealed in a pit of my own filth, than dare tread on the same stage with him.Ladies and gentlemen, the incomparably superior human being, Harry Fink!
Voice Off | He can't come!
Compère | Never mind, it's not all it's cracked up to be. Ladies and gentlemen, we give you Ken Buddha and his inflatable knees.
| Cut to Ken (Terry J) in evening dress; his knees go 'bang'.
Compère | Ken Buddha, a smile, two bangs and a religion. Now ladies and gentlemen, for your further entertainment, Brian Islam and Brucie.
| Two animated men dance to jug band music. When they finish we cut back to the barber and customer.
Barber | So anyway, I became a barber.
Customer | (sympathetically) Poor chap.
Barber | Yes, pity really, I always preferred the outdoor life. Hunting, shooting, fishing. Getting out there with a gun, slaughtering a few of God's creatures - that was the life. Charging about the moorland, blasting their heads off.
| Cut to a large country house. A number of sportin' gentlemen dressed in huntin' tweed and carrying shotguns come out, casually firing the guns at random. They climb into a land-rover and drive off. Cut to huntin' country. A line of beater moves towards the camera; as they do so several young couples leap up out of the undergrowth and run away. Shots of hunters stalking their prey and shooting. One of them breaks his gun into two pieces. Another fires into the air. An egg lands on his head. Cut to two duellists (with pistols) and a referee standing between them. They fire; the referee falls dead. A huntin' gentleman fires into the air, falls over backwards; a young couple gets up from close behind him and run away. Another huntin' gentleman is arguing defensively with a pilot who has just landen by parachute. A hunter fires into some bushes; a Red Indian pops up and runs away in alarm. They all return to the house, legs and arms variously in plaster and bandaged. Two of them carry a pole between them from which is slung a very small bird. The picture of the outside of the house freezes and we pull back to reveal that it is a photo on a stand, by which stands the knight in armour, expectantly flexing his raw chicken. The floor manager comes up to him.
Floor Manager | I'm sorry, we don't need you this week.
| Knight looks dejected, droops and slinks off, still holding chicken. He walks past a hen house from wherein we hear a voice.
Voice | And now for something completely different.
| Cut to a sitting room. Low sexy lighting - ha ha - soft sexy music. On the sofa are Victor and Iris just beginning to make passes at each other.
Victor | Would you mind terribly if I hold your hand?
Iris | Oh no, no, not at all.
Victor | Oh Iris, you're so very beautiful.
Iris | Oh, do you really mean that?
Victor | I do, I do, I do. I think... I'm beginning to fall in love with you.
Iris | Oh Victor.
Victor | It's silly isn't it?
Iris | No, no, not at all dear sweet Victor.
Victor | No I didn't mean that. Only just us being so close together for so many months in the soft-toy department and yet never daring to...
Iris | Oh, oh Victor.
Victor | Oh Iris. (they move closer to kiss; just before their lips meet the doorbell rings) Who can that be?
Iris | Oh, well you try and get rid of them.
Victor | Yes I will, I will.
| Victor opens the front door. Arthur Name is standing outside the door.
Arthur | Hello!
Victor | Hello.
Arthur | Remember me?
Victor | No I'm...
Arthur | In the pub. The tall thin one with the moustache, remember? About three years ago?
Victor | No, I don't I'm afraid.
Arthur | Oh, blimey, it's dark in here, (switches light on) that's better. Only you said we must have a drink together sometime, so I thought I'd take you up on it as the film society meeting was cancelled this evening.
Victor | Look, to be frank, it is a little awkward this evening.
Arthur | (stepping in; to Iris) Hello, I'm Arthur. Arthur Name. Name by name but not by nature. I always say that, don't I Vicky boy?
Victor | Really...
Arthur | (to Victor) Is that your wife?
Victor | Er, no, actually.
Arthur | Oh, I get the picture. Eh? Well don't worry about me Vicky boy, I know all about one-night stands.
Victor | I beg your pardon?
Arthur | Mind if I change the record? (takes the record off)
Victor | Look, look, we put that on.
Arthur | Here's a good one, I heard it in a pub. What's brown, what's brown and sounds like a bell?
Victor | I beg your pardon?
Arthur | What's brown and sounds like a bell? Dung! Ha, ha, ha, that's a good one. I like that one, I won't keep you long. (the gramophone plays the 'Liberty Bell March' very loud) That's better, now don't worry about me. I'll wait here till you've finished.
| The doorbell rings again.
Victor | Who the hell...
Arthur | I'll get it. It'll be friends of mine. I took the liberty of inviting them along.
Victor | Look, we were hoping to have a quiet evening on our own.
Arthur | Oh, they won't mind. They're very broad-minded. Hello!
| He opens the door; Mr and Mrs Equator walk in and go straight up to Victor.
Mr Equator | Good evening. My name is Equator, Mr Equator Equator. Like round the middle of the Earth, only with an L. (wheezing laugh) This is my wife Audrey, she smells a bit but she has a heart of gold.
Audrey | Hello, ha ha ha ha ha ha ha ha ha...
Victor | There must have been some kind of misunderstanding, because this is not the...
Mr Equator | Who's that then?
Victor | What?
Mr Equator | Who's the bird?
Victor | I'm...
Mr Equator | You got a nice pair there haven't you love. (puts hand on Iris's boobs and gives a wet kiss; Iris screams) Shut up you silly bitch, it was only a bit of fun.
Victor | Now look here ...
Mr Equator | Big gin please.
Arthur | I'll get it.
Victor | (going after Arthur) Look, leave those drinks alone.
Audrey | And three tins of beans for me please.
Mr Equator | I told you to lay off the beans, you whore!
Audrey | I only want three cans.
Mr Equator | Button your lip you rat-bag. (laughs uproariously)
Audrey | (joins in) Ha, ha, ha, ha...
Mr Equator | It was rather witty, wasn't it? Where's my gin?
| (The doorbell rings again)
Victor | Who the hell's that?
Mr Equator | Oh, I took the liberty of inviting an old friend along, as his wife has just passed away, and he's somewhat distraught poor chap. I hope you don't mind.
Arthur | (opening door) Come on in.
| In walks Mr Freight in underpants, sequins, eye make-up, white wellies, and necklace.
Mr Freight | Oh? My God, what a simply ghastly place.
Mr Equator | Not too good is it? A pint of crème de menthe for my friend. Well how are you, you great poof? (sits down) Bit lumpy ...ah, no wonder, I was sitting on the cat. (throws it into fire)
Iris | Aaaagh! Boo boo hooo.
Mr Freight | I've asked along a simply gorgeous little man I picked up outside the Odeon.
Mr Equator | Is he sexy?
| In walks Mr Cook with a goat. Freight kisses him.
Mr Cook | I had to bring the goat, he's not well. I only hope he don't go on the carpet.
Mr Equator | (to Iris) Come on then love, drop 'em.
Iris | Aaaaaaagh! (runs out)
Mr Equator | Blimey, she don't go much do she.
| He sits in chair which collapses.
Audrey | Ha, ha, ha, ha, ha, ha, oooooh! I've wet 'em
Mr Cook | The goat's just done a bundle.
| A group of singers run on, dressed as Welsh miners. All talk at once.
Victor | Look, get out all of you. Go on. Get out! Get out!
Mr Equator | I beg your pardon?
Victor | I'm turning you all out. I'm not having my house filled with filthy perverts, now look, I'm giving you just half a minute then I'm going to call the police, so get out.
Mr Equator | I don't much like the tone of your voice. (shoots him) Right let's have a ding dong...
All | (singing) Ding dong merrily on high, in Heaven the bells are ringing etc...
| Cut to 'It's' man
Spanish Voices | (in Spanish) Look out, there are llamas!
| 'It's' man runs away into forest. ROLLER CAPTION: 'THE ANT; AN INTRODUCTION, WAS CONCIEVED, WRITTEN AND PERFORMED BY... (CREDITS)'